<?php
/*-----------------------------------------------------------------------------
 * WWDAS WebAPI Server
 * 
 * 
 * 
 */

	//  Pull in the configuration files.
	//
	require_once( "config.inc.php");

	//  Pull in support libraries and classes.
	//
	require_once( "class.api_user.inc.php");
	require_once( "class.xml_class.inc.php");
	require_once( "class.db_class.inc.php");
	
	$server_version = "1.0";
	$client_version = ( isSet( $_REQUEST[ 'client_version'])) ? $_REQUEST[ 'client_version'] : "Unknown";


	header('Content-type: text/xml;');
	
	$xml = new xmlClass();
	$xml->begin();
	
	$xml->startElement( "heading");
	$xml->set( "server_version", $server_version );
	$xml->set( "client_version", $client_version );
	
	$sql_uri = "{$db_driver}:dbname={$db_name};host={$db_host};charset=utf8";
	
	//  Try opening the database.
	//
	try {
    	$db = new dbClass($sql_uri, $db_user, $db_password );
	} 
	catch (PDOException $e) {
		$xml->set( "status", "FAILED");
		$xml->set( "error_message", "Unable to connect to database: {$e->getMessage()}");
		die( $xml->end());
	}
	
	//  Set the database names so that we can crosslink.
	//
	$db->paxtool_db = $cfg_paxtool_db;
	$db->st_db 		= $cfg_salestool_db;
	
	
	//  Get the API key and check that it is valid. 
	//
	$api_key = isSet( $_REQUEST[ 'api_key' ] ) 
				? strtolower( $_REQUEST[ 'api_key'] )
				: "";
	
	if ( $db->isValidKey( $api_key ) == FALSE ) {
		$xml->set( "status", "FAILED");
		$xml->set( "error_message", "Invalid API key.");
		die( $xml->end());
	}
	
	//  Get the request and force to lower case. 
	//
	$request = ( isSet( $_REQUEST[ 'request']))
		? strtolower( $_REQUEST[ 'request']) 
		: '';
	
	switch( strtolower( $_REQUEST[ 'request'] )) {
		
		case 'vessel_list' :
			$a_vessels = $db->getVesselList();
			$xml->set( "status", "SUCCESS");
			$xml->set( "num_records", count( $a_vessels ));
			$xml->endElement();
			
			$xml->startElement( "results" );
			foreach( $a_vessels as $vessel ) {
				$xml->set( "vessel", $vessel->vessel_name );
			}
			$xml->endElement();
			break;
			
		case 'vessel_trips' :
			
			$vessel_name = (isSet( $_REQUEST[ 'vessel_name' ] ))
							? $_REQUEST[ 'vessel_name']
							: "";

			//  If start date is missing or blank then use today's date.
			//
			$start_date = ( (!isSet( $_REQUEST[ 'start_date' ] )) || ( $_REQUEST[ 'start_date'] == "")) 
							? date( "Y-m-d")
							: date( "Y-m-d", strtotime( $_REQUEST[ 'start_date']));
			
			//  If end date is missing or blank then use the last scheduled date for 
			//  this vessel.
			//
			$end_date	= ( (!isSet( $_REQUEST[ 'end_date' ] )) || ( $_REQUEST[ 'end_date'] == "" ))
							? $db->getLastTripDate()
							: date( "Y-m-d", strtotime( $_REQUEST[ 'end_date']));
			
			$a_trips = $db->getVesselTrips( $vessel_name, $start_date, $end_date );

			$xml->set( "status", "SUCCESS");
			$xml->set( "num_records", count( $a_trips ));
			$xml->endElement();
			
			$xml->startElement( "results" );
			foreach( $a_trips as $trip ) {
				$xml->startElement( "trip");
				foreach( (array)$trip as $name=>$value ) {
					$xml->set( $name, $value );
					}
				$xml->endElement();
			}
			break;
			
		case 'trip_availability' :
			
			$trip_code = ( isSet( $_REQUEST[ 'trip_code']))
							? $_REQUEST[ 'trip_code']
							: "";

			//  If no trip code was specified return an error.
			//
			if ( $trip_code == "" ) {
				$xml->set( "status", "FAILURE");
				$xml->set( "error_message", "Missing trip code");				
			}
			//
			//  Get the availability for the specified trip.  If the trip
			//  is not found this will be FALSE so we catch that.
			//
			elseif ( !( $trip_availability = $db->getTripAvailability( $trip_code ))) {
				$xml->set( "status", "FAILURE");
				$xml->set( "error_message", $db->error_message );
			}
			else {
				$xml->set( "status", "SUCCESS");
				$xml->set( "num_records", count( $trip_availability ));
				$xml->endElement();
			
				$xml->startElement( "results" );
				foreach( (array)$trip_availability as $name=>$value ) {
					$xml->set( $name, $value );
				}
				$xml->endElement();
			}
			
			break;
			
		default :
			$xml->set( "status", "FAILED");
			$xml->set( "error_message", "Invalid function request: '{$request}'.");
			break;
			
	}
	
	// Finalize and output the XML
	//
	$xml->end();

	
	

	?>
