<?php
/*-------------------------------------------------------------------------
 * File		: SCUBATRIBE.PHP
* Author	: D A Dunlop
* Date		: 2014-06-26
*
* Data export routine for ScubaTribe.  Extracts trips for a given vessel
* (or all vessels if none specified) leaving within a given future period,
* along with all guests on those trips.
*
* This data can then be incorporated into the online feedback system that
* ScubaTribe will provide for WWDAS.
*
*/

require_once 'config.inc.php';
require_once 'class.scubatribe_db_class.inc.php';


$days_ahead		= 30;		//  How many days ahead to look -- include trips starting up to this many days ahead.
$days_past		= 1;		//  How many days back to look -- include trips ending up to this many days ago.


$api_key		= isSet( $_GET[ 'api_key' ] )	? $_GET[ 'api_key' ] 	: '';
$vessel			= isSet( $_GET[ 'vessel' ] ) 	? $_GET[ 'vessel' ] 	: '';


//  Try opening the database.
//
try {
	$db_dsn		= "{$db_driver}:dbname={$db_name};host={$db_host};charset=utf8";
	$db 		= new ScubaTribeDBClass( $db_dsn, $db_user, $db_password );
}
catch( PDOException $e ) {
	die ( "\nERROR: Unable to open SQL database connection.\n");
}


//  If the API key is invalid, crash with an error.
//
//	if ( $db->isValidKey( $api_key ) == FALSE ) {
//		die( "ERROR: Invalid API key." );
//	}

$period_past	= new DateInterval( "P{$days_past}D" );
$period_ahead 	= new DateInterval( "P{$days_ahead}D" );


$today = new DateTime();
$start_date = $today->sub( $period_past )->format( "Y-m-d" );

$today = new DateTime();
$end_date	= $today->add( $period_ahead )->format( "Y-m-d" );

$a_results = array();

$a_vessels = $db->getActiveVesselInfo( $vessel );

foreach( $a_vessels as $vessel ) {

	$vessel_info = new stdClass();
	$vessel_info->vessel = $vessel->name;

	switch ( strtoupper( $vessel->booking_manager )) {
		
		case 'PAXTOOL' :
 			$a_trips = $db->getVesselTripsFromPaxtool( $vessel->name, $start_date, $end_date );

 			foreach( $a_trips as $trip ) {
 				$a_guests = $db->getTripGuestsFromPaxtool( $trip->trip_code );
 				$trip->num_guests = count( $a_guests );
 				$trip->guest_list = $a_guests;
 			}
			
			break;
			
			
		case 'BMS' :
			$a_trips = $db->getVesselTripsFromBMS( $vessel->name, $start_date, $end_date );
			
			foreach( $a_trips as $trip ) {
				$a_guests = $db->getTripGuestsFromBMS( $trip->trip_code );
				$trip->num_guests = count( $a_guests );
				$trip->guest_list = $a_guests;
			}
			
			break;
			
			
		default :
			break;
	}
	
	$vessel_info->num_trips = count( $a_trips );
	$vessel_info->trip_list = $a_trips;

	$a_results[ $vessel->name ] = $vessel_info;
}

//  Output content to browser as JSON.
//
header('Content-type: application/json;');
print json_encode( $a_results );





/**
 * Function		: dump()
 * 
 * Debug function to dump the contents of a variable.
 * 
 * @param unknown_type $var
 */
function dump( $var ) {
	
	echo "<pre>";
	print_r( $var );
	echo "</pre>";
}

?>